California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 011 - REDISTRICTING. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1299492 | CALIFORNIA VOTERS FIRST, YES ON 11 FOR CHANGE IN SACRAMENTO - A COALITION OF CONSUMER, SENIOR, PUBLIC INTEREST, TAXPAYER, COMMUNITY AND BUSINESS GROUPS AND LEADERS. MAJOR FUNDING PROVIDED BY GOVERNOR | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307984 | CITIZENS FOR ACCOUNTABILITY - NO ON PROP 11 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1304914 | COMMON CAUSE FOR FAIR REDISTRICTING/ YES ON PROP 11 FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308387 | YES ON 11 - HOLD POLITICIANS ACCOUNTABLE, A COALITION OF CONSUMER, SENIOR, PUBLIC INTEREST, TAXPAYER, COMMUNITY AND BUSINESS GROUPS AND LEADERS | SUPPORT